API Reference — intake_xarray 0.0.1 documentation

# API Reference

`intake_xarray.NetCDFPlugin`() | Plugin for netcdf->xarray reader
`intake_xarray.ZarrPlugin`() | zarr>xarray reader
`intake_xarray.netcdf.NetCDFSource`(urlpath, …) | Open a xarray file.
`intake_xarray.xzarr.ZarrSource`(urlpath[, …]) | Open a xarray dataset.

class `intake_xarray.` `NetCDFPlugin`

  Plugin for netcdf->xarray reader

  Methods

  `open`(urlpath, chunks, **kwargs) | Create NetCDFSource instance

  separate_base_kwargs |

  `open`(urlpath, chunks, **kwargs)

    Create NetCDFSource instance

    Parameters: | urlpath: str Path to source file(s). chunks: int or dict Chunks is used to load the new dataset into dask arrays. `chunks={}` loads the dataset with dask using a single chunk for all arrays.

class `intake_xarray.` `ZarrPlugin`

  zarr>xarray reader

  Methods

  `open`(urlpath[, storage_options]) |
  Parameters: |

  separate_base_kwargs |

  `open`(urlpath, storage_options=None, **kwargs)

    Parameters: | urlpath: str Path to source. This can be a local directory or a remote data service (i.e., with a protocol specifier like `'s3://`). storage_options: dict Parameters passed to the backend file-system kwargs: Further parameters are passed to xr.open_zarr

class `intake_xarray.netcdf.` `NetCDFSource`(urlpath, chunks, xarray_kwargs=None, metadata=None)

  Open a xarray file.

  Parameters: | urlpath: str Path to source file. May include glob “*” characters. Must be a location in the local file-system. chunks: int or dict Chunks is used to load the new dataset into dask arrays. `chunks={}` loads the dataset with dask using a single chunk for all arrays.
  Attributes: | plot

  Methods

  `close`() | Delete open file from memory
  `discover`() | Open resource and populate the source attributes.
  `read`() | Return a version of the xarray with all the data in memory
  `read_chunked`() | Return xarray object (which will have chunks)
  `read_partition`(i) | Fetch one chunk of data at tuple index i
  `to_dask`() | Return xarray object where variables are dask arrays

class `intake_xarray.xzarr.` `ZarrSource`(urlpath, storage_options=None, metadata=None, **kwargs)

  Open a xarray dataset.

  Parameters: | urlpath: str Path to source. This can be a local directory or a remote data service (i.e., with a protocol specifier like `'s3://`). storage_options: dict Parameters passed to the backend file-system kwargs: Further parameters are passed to xr.open_zarr
  Attributes: | plot

  Methods

  `close`() | Delete open file from memory
  `discover`() | Open resource and populate the source attributes.
  `read`() | Return a version of the xarray with all the data in memory
  `read_chunked`() | Return xarray object (which will have chunks)
  `read_partition`(i) | Fetch one chunk of data at tuple index i
  `to_dask`() | Return xarray object where variables are dask arrays

  `close`()

    Delete open file from memory